@@ -267,16 +267,19 @@ def cache(cachename=None,
 
                     diskcache_callstack = check_call_stack(this_function_call)
 
+                reason = ""
                 if not diskcache_exist:
+                    reason = 'does not exist'
                     lgr.debug("Not using diskcache - cachefile does not exist")
                 elif not diskcache_notzero:
+                    reason = 'cache filesize zero'
                     lgr.debug("Not using diskcache - cachefile is empty")
                 elif not diskcache_callstack:
+                    reason = 'callstack changed'
                     lgr.debug("Not using diskcache - callstack changed")
 
-                if (diskcache_exist \
-                    and diskcache_notzero \
-                    and diskcache_callstack):
+                if (diskcache_exist and diskcache_notzero
+                                    and diskcache_callstack):  # NOQA E127
 
                     lgr.info("<D Return from diskcache: %s obj:%s call:%s",
                              basename, objhash, callhash)
@@ -287,6 +290,10 @@ def cache(cachename=None,
                         publish_file(cachefilename, pubfilename)
                     return rv
 
+                lgr.info(f"Not using diskcache because: "
+                         f"'{reason}': %s obj:%s call:%s",
+                         basename, objhash, callhash)
+
             lgr.info("<R (re)running function: %s obj:%s call:%s", basename, objhash, callhash)
             lgr.debug('#### Run function: %s %s %s', func.__name__,
                       objhash, callhash)
@@ -334,8 +341,7 @@ def insert_call_into_stack(called_function):
                                        objhash=frameloc['objhash'],
                                        callhash=frameloc['callhash'])
             save_to_callstack(caller_function, called_function)
-            # only store immediate caller
-            break
+
 
 
 def save_to_callstack(caller_function, called_function):
@@ -361,9 +367,8 @@ def get_called(caller):
     for rec in dbcursor.execute(
             """SELECT called_name, called_objhash, called_callhash
                FROM calls
-               WHERE caller_objhash = ?
-               AND caller_callhash = ?""",
-            (caller.objhash, caller.callhash)):
+               WHERE caller_callhash = ?""",
+            (caller.callhash, )):
 
         called = flufcall(name=rec[0], objhash=rec[1], callhash=rec[2])
         yield caller.name, called
@@ -380,7 +385,7 @@ def check_call_stack(caller):
     self_call_found = False
 
     for _cn, called in get_called(caller):
-        # print('!!!!', caller.name, _cn, called.name, called.objhash)
+        #print('!!!!', caller.name, _cn, called.name, called.objhash)
         if called.objhash == caller.objhash:
             # ~~~ should alwasy be there
             self_call_found = True
